# Notify Service PHP Client

## Installation

In your shell of choice, execute:

`composer require myriad/notify-client-php`

## Quickstart

For maximal compatability, this package does not have any dependencies, so a bit of manual configuration is required. Fortunately for you, if you're using Guzzle 6 or above with Laravel 5 or above, then you should be able to simply copy this [config file](https://bitbucket.org/myriadmobile/godo-web/src/3bc2e57ec15fb4fd70950da4f10cd64f0bceaf90/config/notify.php?at=master&fileviewer=file-view-default) and this [service provider](https://bitbucket.org/myriadmobile/godo-web/src/3bc2e57ec15fb4fd70950da4f10cd64f0bceaf90/app/Providers/NotifyServiceProvider.php?at=master&fileviewer=file-view-default) (don't forget to [add it to your service providers](https://bitbucket.org/myriadmobile/godo-web/src/3bc2e57ec15fb4fd70950da4f10cd64f0bceaf90/config/app.php?at=master&fileviewer=file-view-default#app.php-193)). Then simply instantiate the Client from the container, e.g.

```php
$client = app(Myriad\NotifyClient\Client::class);
```

If you're using an older version of Guzzle, you'll have to adjust the code in the linked service provider to accommodate.
If you're not using Laravel, you can still reference the service provider as an illustration on how to wire up the dependencies the client needs.

## Usage

The main entrypoint for the SDK is the Client:

```php
// If you used the service provider from the Quickstart section, you can do this:
$client = app(Myriad\NotifyClient\Client::class);

// Otherwise, you'll have to manually provide the required dependencies:
$client = new Myriad\NotifyClient\Client(
      new Myriad\NotifyClient\Config($token),
      $httpClient // This must implement `Myriad\NotifyClient\HttpInterface`.
    );
```

To construct a notification, you may use a NotificationBuilder:

```php
$notification = NotificationBuilder::create()
    ->title('Message title')
    ->summary('Message summary')
    ->filter(FilterBuilder::create()->forSubscriptions('weather_warning');
```

The filter restricts the set of registrants that receive the message. `FilterBuilder` can be used to construct many common queries.

To send the notification:
```
$client->createNotification($notification);
```

The `FilterBuilder` may also be used to query notifications and notification groups:

```php
$client->queryNotifications(FilterBuilder::create()->toUids($array_of_uids));
```

If you need to write a fancier query than what the `FilterBuilder` can handle, you can use `FilterBuilder::raw` to construct queries using MongoDB's query syntax:

```php
$filter = FilterBuilder::raw([ 'scheduledAt' => [ '$gte' => Carbon::now()->toRfc3339String() ] ]);
$client->queryNotifications($filter);
```


